import React, { useEffect } from "react";
import * as ReactDOMClient from "react-dom/client";
import "./index.css";
import App from "./App";
import { BrowserRouter, Outlet, Route, Routes } from "react-router-dom";
import Fileset from "./content/Fileset";
import Sync from "./content/Sync";
import Favorite from "./content/Favorite";
import Safebox from "./content/Safebox";
import Recycle from "./content/Recycle";
import Share from "./content/Share";
import Transfer from "./content/Transfer";
import SpinnerIcon from "@rsuite/icons/legacy/Spinner";
import Login from "./Login";

import "rsuite/dist/rsuite.min.css";
import { CustomProvider } from "rsuite";
import { zhCN } from "rsuite/locales";
import Guide from "./Guide";

ReactDOMClient.createRoot(document.getElementById("root")).render(
  <CustomProvider theme={"light"} locale={zhCN}>
    <BrowserRouter>
      <Routes>
        <Route index path={"/"} element={<Loading />}></Route>
        <Route path={"/guide"} element={<Guide />}></Route>
        <Route path={"/app"} element={<App />}>
          <Route index path={"fileset"} element={<Fileset />} />
          <Route path={"sync"} element={<Sync />} />
          <Route path={"favorite"} element={<Favorite />} />
          <Route path={"safebox"} element={<Safebox />} />
          <Route path={"recycle"} element={<Recycle />} />
          <Route path={"share"} element={<Share />} />
          <Route path={"transfer"} element={<Transfer />} />
        </Route>
        <Route path={"/login"} element={<Login />}></Route>
      </Routes>
    </BrowserRouter>
  </CustomProvider>
);

function Loading() {
  useEffect(() => {
    setTimeout(() => {
      window.location.href = "/guide";
    }, 1000);
  }, []);
  return (
    <div className={"flex justify-center items-center w-screen h-screen"}>
      <SpinnerIcon pulse style={{ fontSize: "2em" }} />
    </div>
  );
}
